@@ -5,7 +5,7 @@ import os
 from mopidy import config, ext
 
 
-__version__ = '0.0.1'
+__version__ = '0.1'
 
 
 class BassdriveExtension(ext.Extension):
@@ -20,6 +20,7 @@ class BassdriveExtension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(BassdriveExtension, self).get_config_schema()
+        schema['refresh_archive'] = config.Integer(minimum=0, optional=True)
         return schema
 
     def setup(self, registry):
